==> haskell-project-template-0.2.1.0-354-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 project-template
version:              0.2.1.0
visibility:           public
id:                   project-template-0.2.1.0-7GjwL3meohxHGVbokD2Q5M
key:                  project-template-0.2.1.0-7GjwL3meohxHGVbokD2Q5M
license:              BSD-3-Clause
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/haskell-ide
synopsis:             Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>

category:             Development
abi:                  ac4605ae3694d05ee42aa3c8bcb8459b
exposed:              True
exposed-modules:      Text.ProjectTemplate
import-dirs:          /usr/lib/ghc-9.2.8/site-local/project-template-0.2.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/project-template-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-project-template
hs-libraries:         HSproject-template-0.2.1.0-7GjwL3meohxHGVbokD2Q5M
depends:
    base-4.16.4.0 base64-bytestring-1.2.1.0-GhhDq9m6ztyC3DoGamjFCy
    bytestring-0.11.4.0 conduit-1.3.5-I2k1zAC7fUoKtiTFuyzlnq
    conduit-extra-1.3.6-4TdTAHOIcuFIru5LbcwkQ5 containers-0.6.5.1
    directory-1.3.6.2 filepath-1.4.2.2 mtl-2.2.2
    resourcet-1.2.6-BM5v6tF5II2KPin7i2OBLF text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-project-template/html/project-template.haddock

haddock-html:         /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-project-template-0.2.1.0-356-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 project-template
version:              0.2.1.0
visibility:           public
id:                   project-template-0.2.1.0-LQkraITQ0FFJFXeQlFEZL8
key:                  project-template-0.2.1.0-LQkraITQ0FFJFXeQlFEZL8
license:              BSD-3-Clause
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/haskell-ide
synopsis:             Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>

category:             Development
abi:                  65b9cc772f7853bc30a15e51f1d0cb87
exposed:              True
exposed-modules:      Text.ProjectTemplate
import-dirs:          /usr/lib/ghc-9.2.8/site-local/project-template-0.2.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/project-template-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-project-template
hs-libraries:         HSproject-template-0.2.1.0-LQkraITQ0FFJFXeQlFEZL8
depends:
    base-4.16.4.0 base64-bytestring-1.2.1.0-GhhDq9m6ztyC3DoGamjFCy
    bytestring-0.11.4.0 conduit-1.3.6-3KA9GYcxPBdKwQxn4ENuDV
    conduit-extra-1.3.6-J4oUNnG7RoyAKNqw5asMvk containers-0.6.5.1
    directory-1.3.6.2 filepath-1.4.2.2 mtl-2.2.2
    resourcet-1.2.6-BM5v6tF5II2KPin7i2OBLF text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-project-template/html/project-template.haddock

haddock-html:         /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
